Struct spirv_tools::assembler::DisassembleOptions
source · [−]pub struct DisassembleOptions {
pub print: bool,
pub color: bool,
pub indent: bool,
pub show_byte_offset: bool,
pub no_header: bool,
pub use_friendly_names: bool,
pub comment: bool,
}Fields
print: boolPrint to stdout.
color: boolAdd color codes to output
indent: boolIndent assembly
show_byte_offset: boolno_header: boolDo not output the module header as leading comments in the assembly.
use_friendly_names: boolUse friendly names where possible. The heuristic may expand over time, but will use common names for scalar types, and debug names from OpName instructions.
comment: boolAdd some comments to the generated assembly